@@ -38,18 +38,18 @@
 #include <tqpixmap.h>
 
 #include <kuniqueapplication.h>
-#include <kaboutapplication.h>
-#include <kcmdlineargs.h>
-#include <kwin.h>
+#include <tdeaboutapplication.h>
+#include <tdecmdlineargs.h>
+#include <twin.h>
 #include <kurl.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kiconloader.h>
 #include <kdebug.h>
 #include <kprocess.h>
 #include <dcopclient.h>
 #include <kurldrag.h>
 #include <kservice.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <khelpmenu.h>
 
 #include "pilotRecord.h"
@@ -75,7 +75,7 @@
 
 #include "pilotDaemon.moc"
 
-static KAboutData *aboutData = 0L;
+static TDEAboutData *aboutData = 0L;
 
 PilotDaemonTray::PilotDaemonTray(PilotDaemon * p) :
 	KSystemTray(0, "pilotDaemon"),
@@ -121,7 +121,7 @@ PilotDaemonTray::PilotDaemonTray(PilotDaemon * p) :
 	{
 		case Qt::RightButton:
 			{
-				KPopupMenu *menu = contextMenu();
+				TDEPopupMenu *menu = contextMenu();
 				contextMenuAboutToShow(menu);
 				menu->popup(e->globalPos());
 			}
@@ -144,7 +144,7 @@ void PilotDaemonTray::setupWidget()
 {
 	FUNCTIONSETUP;
 
-	KGlobal::iconLoader()->addAppDir( CSL1("kpilot") );
+	TDEGlobal::iconLoader()->addAppDir( CSL1("kpilot") );
 	icons[Normal] = loadIcon( CSL1("kpilotDaemon") );
 	icons[Busy] = loadIcon( CSL1("busysync") );
 	icons[NotListening] = loadIcon( CSL1("nosync") );
@@ -152,7 +152,7 @@ void PilotDaemonTray::setupWidget()
 	slotShowNotListening();
 	TQTimer::singleShot(2000,this,TQT_SLOT(slotShowNormal()));
 
-	KPopupMenu *menu = contextMenu();
+	TDEPopupMenu *menu = contextMenu();
 
 	menuKPilotItem = menu->insertItem(i18n("Start &KPilot"), daemon,
 		TQT_SLOT(slotRunKPilot()));
@@ -160,7 +160,7 @@ void PilotDaemonTray::setupWidget()
 		daemon, TQT_SLOT(slotRunConfig()));
 	menu->insertSeparator();
 
-	fSyncTypeMenu = new KPopupMenu(menu,"sync_type_menu");
+	fSyncTypeMenu = new TDEPopupMenu(menu,"sync_type_menu");
 	TQString once = i18n("Appended to names of sync types to indicate the sync will happen just one time"," (once)");
 #define MI(a) fSyncTypeMenu->insertItem( \
 		SyncAction::SyncMode::name(SyncAction::SyncMode::a) + once, \
@@ -186,7 +186,7 @@ void PilotDaemonTray::setupWidget()
 
 	KHelpMenu *help = new KHelpMenu(menu,aboutData);
 	menu->insertItem(
-		KGlobal::iconLoader()->loadIconSet(CSL1("help"),KIcon::Small,0,true),
+		TDEGlobal::iconLoader()->loadIconSet(CSL1("help"),TDEIcon::Small,0,true),
 		i18n("&Help"),help->menu(),false /* no whatsthis */);
 
 
@@ -202,7 +202,7 @@ void PilotDaemonTray::slotShowAbout()
 
 	if (!kap)
 	{
-		kap = new KAboutApplication(0, "kpdab", false);
+		kap = new TDEAboutApplication(0, "kpdab", false);
 	}
 
 	kap->show();
@@ -742,7 +742,7 @@ static void fillConduitNameMap()
 		if (!conduitNameMap->find(*i))
 		{
 			TQString readableName = CSL1("<unknown>");
-			KSharedPtr < KService > o = KService::serviceByDesktopName(*i);
+			TDESharedPtr < KService > o = KService::serviceByDesktopName(*i);
 			if (!o)
 			{
 				WARNINGKPILOT << "No service for " << *i << endl;
@@ -804,7 +804,7 @@ static KDesktopLockStatus isKDesktopLockRunning()
 {
 	if (!KPilotSettings::screenlockSecure()) return NotLocked;
 
-	DCOPClient *dcopptr = KApplication::kApplication()->dcopClient();
+	DCOPClient *dcopptr = TDEApplication::kApplication()->dcopClient();
 
 	// Can't tell, very weird, err on the side of safety.
 	if (!dcopptr || !dcopptr->isAttached())
@@ -1208,9 +1208,9 @@ void PilotDaemon::slotRunKPilot()
 	TQCString kpilotDCOP;
 	int kpilotPID;
 
-	if (KApplication::startServiceByDesktopName(CSL1("kpilot"),
+	if (TDEApplication::startServiceByDesktopName(CSL1("kpilot"),
 			TQString(), &kpilotError, &kpilotDCOP, &kpilotPID
-#if (KDE_VERSION >= 220)
+#if (TDE_VERSION >= 220)
 			// Startup notification added in 2.2
 			, ""
 #endif
@@ -1236,13 +1236,13 @@ void PilotDaemon::slotRunConfig()
 	// If it succeeds, we can assume kpilot is running and then try
 	// to send the configure() DCOP call.
 	// If it fails (probably because kpilot isn't running) it tries
-	// to call kpilot via KProcess (using a command line switch to
+	// to call kpilot via TDEProcess (using a command line switch to
 	// only bring up the configure dialog).
 	//
 	// Implementing the function this way catches all cases.
 	// ie 1 KPilot running with configure dialog open (raise())
 	//    2 KPilot running with dialog NOT open (configureConduits())
-	//    3 KPilot NOT running (KProcess)
+	//    3 KPilot NOT running (TDEProcess)
 
 	DCOPClient *client = kapp->dcopClient();
 
@@ -1257,7 +1257,7 @@ void PilotDaemon::slotRunConfig()
 	else
 	{
 		// KPilot not running
-		KProcess *p = new KProcess;
+		TDEProcess *p = new TDEProcess;
 		*p << "kpilot" << "-s";
 
 		p->start();
@@ -1291,13 +1291,13 @@ void PilotDaemon::updateTrayStatus(const TQString &s)
 	emitDCOPSignal( "kpilotDaemonStatusDetails(TQDateTime,TQString,TQStringList,TQString,TQString,TQString,bool)", data );
 }
 
-static KCmdLineOptions daemonoptions[] = {
+static TDECmdLineOptions daemonoptions[] = {
 #ifdef DEBUG
 	{"debug <level>", I18N_NOOP("Set debugging level"), "0"},
 #endif
 	{ "device <device>", I18N_NOOP("Device to try first"), ""},
 	{"fail-silently", I18N_NOOP("Exit instead of complaining about bad configuration files"), 0},
-	KCmdLineLastOption
+	TDECmdLineLastOption
 } ;
 
 
@@ -1305,13 +1305,13 @@ int main(int argc, char **argv)
 {
 	FUNCTIONSETUP;
 
-	KLocale::setMainCatalogue("kpilot");
+	TDELocale::setMainCatalogue("kpilot");
 
-	KAboutData about("kpilotDaemon",
+	TDEAboutData about("kpilotDaemon",
 		I18N_NOOP("KPilot Daemon"),
 		KPILOT_VERSION,
-		"KPilot - HotSync software for KDE\n\n",
-		KAboutData::License_GPL,
+		"KPilot - HotSync software for TDE\n\n",
+		TDEAboutData::License_GPL,
 		"(c) 1998-2000,2001, Dan Pilone (c) 2000-2004, Adriaan de Groot",
 		0L,
 		"http://www.kpilot.org/"
@@ -1328,10 +1328,10 @@ int main(int argc, char **argv)
 	aboutData = &about;
 
 
-	KCmdLineArgs::init(argc, argv, &about);
-	KCmdLineArgs::addCmdLineOptions(daemonoptions,"kpilotconfig");
+	TDECmdLineArgs::init(argc, argv, &about);
+	TDECmdLineArgs::addCmdLineOptions(daemonoptions,"kpilotconfig");
 	KUniqueApplication::addCmdLineOptions();
-	KCmdLineArgs *p = KCmdLineArgs::parsedArgs();
+	TDECmdLineArgs *p = TDECmdLineArgs::parsedArgs();
 
 #ifdef DEBUG
 	KPilotConfig::getDebugLevel(p);
